# risk_model_maidou
wu,jian


Automatic modeling code built based on my experience in scorecard modeling in recent years. It mainly includes the following functions:

- Woe automatic bin splitting, directly get the optimal bin splitting
- Logistic regression modeling（stepwise and ensemble）
- Scorecard score calibration and prediction

基于我近年来在评分卡建模方面的经验构建的自动建模代码。主要包括以下功能：

- Woe自动分箱，直接获得最佳分箱

- 逻辑回归建模（逐步回归和一些集成模型）

- 打分卡分数校准和预测打分

还有很多代码可以打包，这次仅作尝试，慢慢添加。